Crate jupiter_api_rs

Crate jupiter_api_rs 

Rust client for Jupiter APIs generated from the repository’s OpenAPI specs.

Modules

jupiter
Generated client and types for endpoints hosted at https://api.jup.ag. Generated API modules
tx
Generated client and types for transaction submission at https://tx.jup.ag. Generated API modules

Functions

create_jupiter_api
Creates a Jupiter API client configured with the required x-api-key header.
create_jupiter_tx_api
Creates a transaction-submission client configured with the required x-api-key header.

Type Aliases

JupiterApi
Generated client for endpoints hosted at https://api.jup.ag.
JupiterTxApi
Generated client for transaction submission at https://tx.jup.ag.