pub struct PatchTriggerV2OrdersPriceOrderIdRequest {
pub order_type: PatchTriggerV2OrdersPriceOrderIdRequestOrderType,
pub sl_price_usd: Option<f64>,
pub sl_slippage_bps: Option<f64>,
pub slippage_bps: Option<f64>,
pub tp_price_usd: Option<f64>,
pub tp_slippage_bps: Option<f64>,
pub trailing_bps: Option<f64>,
pub trigger_price_usd: Option<f64>,
}Fields
order_type: PatchTriggerV2OrdersPriceOrderIdRequestOrderTypesl_price_usd: Option<f64>sl_slippage_bps: Option<f64>slippage_bps: Option<f64>tp_price_usd: Option<f64>tp_slippage_bps: Option<f64>trailing_bps: Option<f64>New trailing stop loss trail distance in basis points (50-9000), for an order that is already trailing. Constraint: minimum=50, maximum=9000
trigger_price_usd: Option<f64>New trigger price. Cannot be set on a trailing stop loss order.
Implementations
Sourceimpl PatchTriggerV2OrdersPriceOrderIdRequest
impl PatchTriggerV2OrdersPriceOrderIdRequest
Sourcepub fn new(order_type: PatchTriggerV2OrdersPriceOrderIdRequestOrderType) -> Self
pub fn new(order_type: PatchTriggerV2OrdersPriceOrderIdRequestOrderType) -> Self
Construct this request with every required wire field.
Sourcepub fn builder(
order_type: PatchTriggerV2OrdersPriceOrderIdRequestOrderType,
) -> PatchTriggerV2OrdersPriceOrderIdRequestBuilder
pub fn builder( order_type: PatchTriggerV2OrdersPriceOrderIdRequestOrderType, ) -> PatchTriggerV2OrdersPriceOrderIdRequestBuilder
Start a dependency-free builder with every required wire field.