pub struct PostExecuteResponse {
pub code: Option<f64>,
pub error: Option<String>,
pub input_amount_result: Option<String>,
pub output_amount_result: Option<String>,
pub signature: Option<String>,
pub slot: Option<String>,
pub status: Option<PostExecuteResponseStatus>,
pub swap_events: Option<Vec<SwapV2SwapEvent>>,
pub total_input_amount: Option<String>,
pub total_output_amount: Option<String>,
}Fields
code: Option<f64>- Error code. 0 = success.
- Ultra: -1 (missing cached order), -2 (invalid signed tx), -3 (invalid message bytes).
- Aggregator: -1000 (failed to land), -1001 (unknown), -1002 (invalid tx), -1003 (not fully signed), -1004 (invalid block height).
- RFQ: -2000 (failed to land), -2001 (unknown), -2002 (invalid payload), -2003 (quote expired), -2004 (swap rejected).
error: Option<String>Error message (present if Failed)
input_amount_result: Option<String>Input amount that went into the swap route, after any fee collected in the input mint
output_amount_result: Option<String>Output amount produced by the swap route, before any fee collected in the output mint
signature: Option<String>Transaction signature
slot: Option<String>Confirmed slot
status: Option<PostExecuteResponseStatus>swap_events: Option<Vec<SwapV2SwapEvent>>total_input_amount: Option<String>Total input token amount deducted from the user’s wallet, including the fee if feeMint is the input mint
total_output_amount: Option<String>Final output token amount reflected in the user’s wallet, after any fee collected in the output mint