pub struct PostSendV1CraftClawbackRequest {
pub invite_pda: String,
pub sender: String,
}Fields
invite_pda: String- Program Derived Address derived by
"invite"and the public key of the invite- Do note that, the invitePDA requires to be generated client side, refer to docs
- Please handle invite code and secret key with highest security as user funds are involved
sender: String- Public key address of the sender
- Since this address funded the invite, it will be the receiving address of the full amount