PostSendV1CraftSendRequest

Struct PostSendV1CraftSendRequest 

pub struct PostSendV1CraftSendRequest {
    pub amount: String,
    pub invite_signer: String,
    pub mint: Option<String>,
    pub sender: String,
}

Fields

amount: String
  • Amount in atomic value (before decimals)
    • E.g. to send 1 USDC is equivalent of amount='1000000'
    • Do note that there will be additional SOL amount being used in the transaction for transaction fees and token accounts
invite_signer: String
  • Public key address generated from the hash of the invite code
    • Do note that, the invite code requires to be generated client side, refer to docs
    • Please handle invite code and secret key with highest security as user funds are involved
mint: Option<String>
  • Defaults to WSOL mint
    • Only pass in this parameter with other mint when required
sender: String
  • Public key address of the sender
    • This address will be funding the amount to be sent and the token accounts involved

Implementations

Source

impl PostSendV1CraftSendRequest

pub fn new(amount: String, invite_signer: String, sender: String) -> Self

Construct this request with every required wire field.

pub fn builder( amount: String, invite_signer: String, sender: String, ) -> PostSendV1CraftSendRequestBuilder

Start a dependency-free builder with every required wire field.