pub struct PostTriggerV1CreateOrderRequestParams {
pub expired_at: Option<String>,
pub fee_bps: Option<String>,
pub making_amount: String,
pub slippage_bps: Option<String>,
pub taking_amount: String,
}Fields
expired_at: Option<String>fee_bps: Option<String>Requires the feeAccount parameter, the amount of fees in bps that will be sent to the fee account
making_amount: StringAmount of input mint to swap
slippage_bps: Option<String>Amount of slippage the order can be executed with
taking_amount: StringAmount of output mint to receive