PredictionCreateOrderResponseOrder

Struct PredictionCreateOrderResponseOrder 

pub struct PredictionCreateOrderResponseOrder {
Show 27 fields pub contracts: String, pub contracts_decimal: Option<String>, pub contracts_micro: Option<String>, pub estimated_protocol_fee_usd: String, pub estimated_total_fee_usd: String, pub estimated_venue_fee_usd: String, pub external_order_id: Option<String>, pub is_buy: bool, pub is_yes: bool, pub market_id: String, pub market_id_hash: String, pub max_buy_price_usd: Option<String>, pub max_slippage_bps: Option<i64>, pub min_sell_price_usd: Option<String>, pub new_avg_price_usd: String, pub new_contracts: String, pub new_contracts_decimal: Option<String>, pub new_contracts_micro: Option<String>, pub new_payout_usd: String, pub new_size_usd: String, pub order_ata_pubkey: Option<String>, pub order_cost_usd: String, pub order_pubkey: Option<String>, pub payout_usd: Option<String>, pub position_pubkey: String, pub slippage_bps: Option<i64>, pub user_pubkey: String,
}

Fields

contracts: String

Legacy whole-contract quantity. Use contractsMicro or contractsDecimal for the exact fractional quantity.

contracts_decimal: Option<String>

Contracts as a decimal string

contracts_micro: Option<String>

Contracts in micro-contract units (u64 as string, 1000000 = 1 contract)

estimated_protocol_fee_usd: String

Estimated protocol fee (micro USD)

estimated_total_fee_usd: String

Estimated total fees applied (micro USD)

estimated_venue_fee_usd: String

Estimated venue fee (micro USD)

external_order_id: Option<String>

Client provided order identifier

is_buy: bool

True when the order increases exposure

is_yes: bool

True when the order is on the YES side

market_id: String

Associated market identifier

market_id_hash: String

Hashed market identifier used for on-chain PDAs

max_buy_price_usd: Option<String>

Max fill price for buys (micro USD)

max_slippage_bps: Option<i64>

Maximum slippage allowed for this order, in basis points Constraint: minimum=0

min_sell_price_usd: Option<String>

Min fill price for sells (micro USD)

new_avg_price_usd: String

Average position entry price after the order

new_contracts: String

Position contracts after executing the order (legacy whole-contract quantity)

new_contracts_decimal: Option<String>

Position contracts after the order, as a decimal string

new_contracts_micro: Option<String>

Position contracts after the order, in micro-contract units

new_payout_usd: String

Position max payout after the order

new_size_usd: String

Total position cost basis after the order

order_ata_pubkey: Option<String>

Order escrow token account

order_cost_usd: String

Notional for this order in micro USD

order_pubkey: Option<String>

Order account public key

payout_usd: Option<String>

Position max payout for this order (micro USD)

position_pubkey: String

Position PDA used for the order

slippage_bps: Option<i64>

Estimated slippage for this order, in basis points (0 = none, 250 = 2.5%). For a Polymarket buy this is the estimated price impact from sweeping orderbook levels; for a sell it is the max allowed slippage from best bid to the protected sell floor. Treat it as a quote signal, not a guaranteed loss. Constraint: minimum=0

user_pubkey: String

Order owner public key