pub struct StudioCreateDBCTransactionRequestBody {
pub anti_sniping: bool,
pub build_curve_by_market_cap_param: StudioCreateDBCTransactionRequestBodyBuildCurveByMarketCapParam,
pub creator: String,
pub fee: StudioCreateDBCTransactionRequestBodyFee,
pub is_lp_locked: Option<bool>,
pub token_image_content_type: StudioCreateDBCTransactionRequestBodyTokenImageContentType,
pub token_name: String,
pub token_symbol: String,
}Fields
anti_sniping: bool- Enable anti-sniping protection
- Apply an additional swap fee immediately after launch to discourage bots
- Starts at 99% and decreases 1% linearly over a randomized period
build_curve_by_market_cap_param: StudioCreateDBCTransactionRequestBodyBuildCurveByMarketCapParamcreator: String- Creator wallet public key
fee: StudioCreateDBCTransactionRequestBodyFee- Fee configuration parameters
- If not provided, the default fee will be 100 basis points (1%)
is_lp_locked: Option<bool>- Whether LP tokens should be locked
- If enabled, 50% of graduated LP unlocks after 1 year
- Useful for creators to strategize in the long term
token_image_content_type: StudioCreateDBCTransactionRequestBodyTokenImageContentType- Token image content type
token_name: StringConstraint: minLength=1
token_symbol: StringConstraint: minLength=1
Implementations
Sourceimpl StudioCreateDBCTransactionRequestBody
impl StudioCreateDBCTransactionRequestBody
Sourcepub fn new(
anti_sniping: bool,
build_curve_by_market_cap_param: StudioCreateDBCTransactionRequestBodyBuildCurveByMarketCapParam,
creator: String,
fee: StudioCreateDBCTransactionRequestBodyFee,
token_image_content_type: StudioCreateDBCTransactionRequestBodyTokenImageContentType,
token_name: String,
token_symbol: String,
) -> Self
pub fn new( anti_sniping: bool, build_curve_by_market_cap_param: StudioCreateDBCTransactionRequestBodyBuildCurveByMarketCapParam, creator: String, fee: StudioCreateDBCTransactionRequestBodyFee, token_image_content_type: StudioCreateDBCTransactionRequestBodyTokenImageContentType, token_name: String, token_symbol: String, ) -> Self
Construct this request with every required wire field.
Sourcepub fn builder(
anti_sniping: bool,
build_curve_by_market_cap_param: StudioCreateDBCTransactionRequestBodyBuildCurveByMarketCapParam,
creator: String,
fee: StudioCreateDBCTransactionRequestBodyFee,
token_image_content_type: StudioCreateDBCTransactionRequestBodyTokenImageContentType,
token_name: String,
token_symbol: String,
) -> StudioCreateDBCTransactionRequestBodyBuilder
pub fn builder( anti_sniping: bool, build_curve_by_market_cap_param: StudioCreateDBCTransactionRequestBodyBuildCurveByMarketCapParam, creator: String, fee: StudioCreateDBCTransactionRequestBodyFee, token_image_content_type: StudioCreateDBCTransactionRequestBodyTokenImageContentType, token_name: String, token_symbol: String, ) -> StudioCreateDBCTransactionRequestBodyBuilder
Start a dependency-free builder with every required wire field.