pub struct StudioCreateDBCTransactionResponse {
pub image_presigned_url: Url,
pub image_url: Url,
pub metadata_presigned_url: Url,
pub mint: String,
pub transaction: String,
}Fields
image_presigned_url: Url- Presigned URL for image upload via
PUTrequest- This is for you to make a PUT request to upload your token image to the on-chain uri metadata
- Refer to the Token Metadata section for better understanding
image_url: UrlFinal image URL
metadata_presigned_url: Url- Presigned URL for metadata upload via
PUTrequest- This is for you to make a PUT request to upload your token metadata to the on-chain uri metadata
- Refer to the Token Metadata section for better understanding
mint: StringGenerated token mint address
transaction: StringBase64-encoded transaction ready for signing