pub struct StudioSubmitDBCTransactionRequestBody {
pub content: Option<String>,
pub header_image: Option<Bytes>,
pub owner: String,
pub transaction: String,
}Fields
content: Option<String>- Optional content description displayed on Studio dedicated token page
- This is stored off-chain for our frontend to display
- This is NOT the on-chain token metadata
- The on-chain token metadata is done by making a PUT request to the presigned URL
header_image: Option<Bytes>- Optional header image file displayed on Studio token page
- This is stored off-chain for our frontend to display
- This is NOT the on-chain token metadata
- The on-chain token metadata is done by making a PUT request to the presigned URL
owner: String- Owner wallet public key
transaction: String- Base64-encoded signed transaction
Implementations