pub struct GetUltraV1OrderResponse {Show 36 fields
pub error_code: Option<f64>,
pub error_message: Option<GetUltraV1OrderResponseErrorMessage>,
pub expire_at: Option<String>,
pub fee_bps: f64,
pub fee_mint: Option<String>,
pub gasless: bool,
pub in_amount: String,
pub in_usd_value: Option<f64>,
pub input_mint: String,
pub maker: Option<String>,
pub mode: String,
pub other_amount_threshold: String,
pub out_amount: String,
pub out_usd_value: Option<f64>,
pub output_mint: String,
pub platform_fee: GetUltraV1OrderResponsePlatformFee,
pub price_impact: Option<f64>,
pub price_impact_pct: String,
pub prioritization_fee_lamports: f64,
pub prioritization_fee_payer: Option<String>,
pub quote_id: Option<String>,
pub referral_account: Option<String>,
pub rent_fee_lamports: f64,
pub rent_fee_payer: Option<String>,
pub request_id: String,
pub route_plan: Vec<GetUltraV1OrderResponseRoutePlanItem>,
pub router: GetUltraV1OrderResponseRouter,
pub signature_fee_lamports: f64,
pub signature_fee_payer: Option<String>,
pub slippage_bps: f64,
pub swap_mode: String,
pub swap_type: String,
pub swap_usd_value: Option<f64>,
pub taker: Option<String>,
pub total_time: f64,
pub transaction: Option<String>,
}Fields
error_code: Option<f64>- This field will be present if
takeris defined andtransactionis an empty string- It is unique for each error scenarios
error_message: Option<GetUltraV1OrderResponseErrorMessage>- This field will be present if
takeris defined andtransactionis an empty string- This field can still return despite having a valid order/quote
- This is meant for display purposes only and it is discouraged to match these error messages as they could be parameterized
expire_at: Option<String>fee_bps: f64- The fee includes either Ultra default fee or your integrator fee, depending on if referral and/or payer params are passed in
- If
referralAccount,referralFee(andpayerif passed in) are passed in, the fee will be the integrator fee only - If no additional referral params are passed in, the fee will be the Ultra default fee only and can include additional fees for gasless support mechanism
- If
fee_mint: Option<String>gasless: boolin_amount: Stringin_usd_value: Option<f64>input_mint: Stringmaker: Option<String>mode: Stringother_amount_threshold: Stringout_amount: Stringout_usd_value: Option<f64>output_mint: Stringplatform_fee: GetUltraV1OrderResponsePlatformFee- This field shows the platform fee only, does not include fee for gas
- Platform fee can either be the Ultra default fee or your integrator fee
price_impact: Option<f64>price_impact_pct: String- Please use
priceImpactfield instead, this is still available only for backwards compatibility
prioritization_fee_lamports: f64- The number of lamports the
taker,maker(JupiterZ’s MM) orpayerhas to pay for higher priority landing, if a valid transaction is returned- Includes priority fees and tips for services such as Jito, etc, if any
prioritization_fee_payer: Option<String>- The public key of the account that will cover the prioritization fee, it can be either
taker,maker(JupiterZ’s MM) orpayerif passed in
quote_id: Option<String>referral_account: Option<String>rent_fee_lamports: f64- The number of lamports the
takerorpayerhas to pay for account rent, if a valid transaction is returned- Note that this value is just an estimate
- For JupiterZ quotes, Jupiter’s gas wallet pays the rent to create the taker’s output token account if not yet initialised
rent_fee_payer: Option<String>- The public key of the account that will cover the rent fee, it can be either
taker,payerif passed in, or Jupiter’s gas wallet for JupiterZ quotes when the taker’s output token account is not yet initialised
request_id: String- Required to make a request to
/execute
route_plan: Vec<GetUltraV1OrderResponseRoutePlanItem>router: GetUltraV1OrderResponseRoutersignature_fee_lamports: f64- The number of lamports the
taker,maker(JupiterZ’s MM) orpayerhas to pay for the base network fee, if a valid transaction is returned.
signature_fee_payer: Option<String>- The public key of the account that will cover the signature fee, it can be either
taker,maker(JupiterZ’s MM) orpayerif passed in
slippage_bps: f64swap_mode: Stringswap_type: String- Deprecated, in favour of router
swap_usd_value: Option<f64>taker: Option<String>total_time: f64transaction: Option<String>- Unsigned base-64 encoded transaction to be signed and used in
/execute- If
takeris null, this field will be null. - If the
transactionfield is empty, it is returned witherrorCodeanderrorMessagesuch as Insufficient Funds
- If