pub struct PredictionCreateOrderResponse {
pub execution: Option<PredictionExecution>,
pub execution_model: Option<String>,
pub external_order_id: Option<String>,
pub jupiter_swap_request_id: Option<String>,
pub order: PredictionCreateOrderResponseOrder,
pub required_signers: Option<Vec<String>>,
pub settlement: Option<String>,
pub transaction: Option<String>,
pub tx_meta: Option<PredictionCreateOrderResponseTxMeta>,
}Fields
execution: Option<PredictionExecution>execution_model: Option<String>Execution model for the order. atomic_swap for Jupiter Forecast (bisonfi) orders, which execute as a single atomic swap through POST /execute. null for keeper-filled prediction orders.
external_order_id: Option<String>jupiter_swap_request_id: Option<String>Jupiter swap request id when the order executes as a swap (Jupiter Forecast). null otherwise.
order: PredictionCreateOrderResponseOrderrequired_signers: Option<Vec<String>>Public keys that must sign the returned transaction
settlement: Option<String>Settlement mode. auto for Jupiter Forecast orders, which settle automatically. null for keeper-filled prediction orders.
transaction: Option<String>Base64 encoded transaction
tx_meta: Option<PredictionCreateOrderResponseTxMeta>Transaction metadata